=== modified file 'doc/developers/bug-handling.txt'
--- doc/developers/bug-handling.txt	2009-08-24 20:16:15 +0000
+++ doc/developers/bug-handling.txt	2009-09-15 05:16:50 +0000
@@ -157,10 +157,17 @@
     A fix for this bug exists in a branch somewhere.  Ideally the bug will
     be linked to the branch.
 Fix Released
-    The fix for this bug is now in the bzr trunk.  It's not necessarily
-    true that it's released yet, but it will be in the next release.  The
-    bug target milestone should be set to the release it went into, but
-    don't spend too much time updating this if you don't immediately know.
+    The fix for this bug is now in the bzr branch that this task is for.
+    The branch for the default task on a bug is bzr.dev.  We use this value
+    even though the fix may not have been been included in a release yet
+    because all the developer activity around it is complete and we want to
+    both avoid bug spam when releases happen, and keep the list of bugs that
+    developers see when they look at the bug tracker trimmed to those that
+    require action. When setting a bug task to fix released, the bug target
+    milestone should be set to the release the fix will be included in (or
+    was included in, if you are updating an old bug). Don't spend too much time
+    updating this if you don't immediately know: its not critical that it be
+    set.
 
 
 Bug Importance
@@ -204,16 +211,14 @@
 ***************
 
 It's possible to target a bug to a milestone, eg
-<https://bugs.edge.launchpad.net/bzr/+milestone/1.16>.  We use this mostly
-to help the release manager know what **must** be merged to make the
-release.
+<https://bugs.edge.launchpad.net/bzr/+milestone/1.16>.  We use this to help the
+release manager know what **must** be merged to make the release.
 
 Therefore, we don't target bugs that we'd like to have fixed or that could
 be fixed in a particular release, we only target bugs that must be fixed
-and that will or might cause us to decide to slip the release if they're
-not fixed.  At any time, very few if any of the bugs targetted to a
-release should be still open.  By definition, these bugs should normally
-be Critical priority.
+and that will cause us to slip the release if they're not fixed.  At any time,
+very few if any of the bugs targeted to a release should be still open.  By
+definition, these bugs should normally be Critical priority.
 
 
 Backports
@@ -224,8 +229,10 @@
 represent this, create a new bug task (ie link in the status table on the
 bug page) by clicking the `poorly-named
 <https://bugs.launchpad.net/bugs/132733>`_ "Target to Release" link.
-Target it to the appropriate series (ie 1.15) and then to the milestone
-within that release.  
+Target it to the appropriate series (ie 1.15). If the bug should also
+prevent any point releases of that series then you should also target the
+new task to the appropriate milestone within that release. (See Targeting Bugs
+above)
 
 This bug task then has a separate status and importance to indicate the
 separate work to get it into that release.

=== modified file 'doc/developers/integration.txt'
--- doc/developers/integration.txt	2009-09-09 02:21:47 +0000
+++ doc/developers/integration.txt	2009-09-15 06:07:11 +0000
@@ -197,7 +197,7 @@
 
   from bzrlib import branch
 
-  b = branch.Branch.open('http://bazaar-vcs.org/bzr/bzr.dev')
+  b = branch.Branch.open('http://bazaar.launchpad.net/~bzr-pqm/bzr/bzr.dev')
   nb = b.bzrdir.sprout('/tmp/newBzrBranch').open_branch()
 
 
@@ -213,7 +213,7 @@
   from bzrlib import branch
 
   b1 = branch.Branch.open('file:///home/user/mybranch')
-  b2 = branch.Branch.open('http://bazaar-vcs.org/bzr/bzr.dev')
+  b2 = branch.Branch.open('http://bazaar.launchpad.net/~bzr-pqm/bzr/bzr.dev')
   b1.push(b2)
 
 

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2009-09-11 07:55:48 +0000
+++ doc/developers/releasing.txt	2009-09-15 06:07:11 +0000
@@ -27,10 +27,10 @@
 #. Create a new series at <https://launchpad.net/bzr/+addseries>. There is one
    series for every *x.y* release.
 
-#. Go to the series web page at <https://launchpad.net/bzr/2.0>
+#. Go to the series web page at <https://launchpad.net/bzr/x.y>
 
 #. Create a new release at
-   <https://launchpad.net/bzr/2.0/+addrelease> and add
+   <https://launchpad.net/bzr/x.y/+addrelease> and add
    information about this release. We will not use it yet, but it
    will be available for targeting or nominating bugs.
 
@@ -40,7 +40,7 @@
    general development continues on the trunk, and only
    specifically-targeted fixes go into the release branch.
 
-#. Add milestones at <https://edge.launchpad.net/bzr/2.0/+addmilestone> to
+#. Add milestones at <https://edge.launchpad.net/bzr/x.y/+addmilestone> to
    that series for the beta release, release candidate and the final release,
    and their expected dates.
 
@@ -59,10 +59,8 @@
 
 When it's time to make the first beta release or release candidate:
 
-#. Create a new milestone at <https://launchpad.net/bzr/2.0/+addmilestone>
-   for the beta release or release candidate.
-
-#. Make a beta release or release candidate.
+#. Make a beta release or release candidate. The milestone for this
+   candidate will already exist (see Starting a cycle above).
 
 Preparing the tree for release
 ------------------------------
@@ -72,13 +70,14 @@
 
      bzr branch trunk prepare-1.14
 
-#. Configure pqm-submit for this branch, with a section like this in
+#. Configure pqm-submit for this branch, with a section like this (where
+   x.y is the version to release).
    ``~/.bazaar/locations.conf``::
 
-	[/home/mbp/bzr/prepare-1.14]
+	[/home/mbp/bzr/prepare-x.y]
 	pqm_email = Canonical PQM <pqm@bazaar-vcs.org>
-	submit_branch = lp:bzr/2.0
-	public_branch = http://bazaar.example.com/prepare-2.0
+	submit_branch = http://bazaar.launchpad.net/~bzr-pqm/bzr/x.y
+	public_branch = http://bazaar.example.com/prepare-x.y
 	submit_to = bazaar@lists.canonical.com
 	smtp_server = mail.example.com:25
 

